@@ -1,5 +1,6 @@
 """``runway run-python`` command."""
 # docs: file://./../../../docs/source/commands.rst
+import locale
 from pathlib import Path
 from typing import Any
 
@@ -32,5 +33,9 @@ def run_python(filename: str, **_: Any) -> None:
     # override name & file so script operates as if it were invoked directly
     execglobals.update({"__name__": "__main__", "__file__": filename})
     exec(  # pylint: disable=exec-used
-        Path(filename).read_text(), execglobals, execglobals
+        Path(filename).read_text(
+            encoding=locale.getpreferredencoding(do_setlocale=False)
+        ),
+        execglobals,
+        execglobals,
     )
