@@ -11,16 +11,17 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+from __future__ import annotations
+
 import json
+from typing import Any, Dict, MutableMapping, MutableSequence, cast
 
 import yaml
-from botocore.compat import six
-from yaml.resolver import ScalarNode, SequenceNode
 
 
 def intrinsics_multi_constructor(  # pylint: disable=unused-argument
-    loader, tag_prefix, node
-):
+    loader: yaml.Loader, tag_prefix: str, node: yaml.Node
+) -> Dict[str, Any]:
     """YAML constructor to parse CloudFormation intrinsics.
 
     This will return a dictionary with key being the intrinsic name
@@ -36,33 +37,33 @@ def intrinsics_multi_constructor(  # pylint: disable=unused-argument
 
     cfntag = prefix + tag
 
-    if tag == "GetAtt" and isinstance(node.value, six.string_types):
+    if tag == "GetAtt" and isinstance(node.value, str):
         # ShortHand notation for !GetAtt accepts Resource.Attribute format
         # while the standard notation is to use an array
         # [Resource, Attribute]. Convert shorthand to standard format
         value = node.value.split(".", 1)
 
-    elif isinstance(node, ScalarNode):
+    elif isinstance(node, yaml.ScalarNode):
         # Value of this node is scalar
         value = loader.construct_scalar(node)
 
-    elif isinstance(node, SequenceNode):
+    elif isinstance(node, yaml.SequenceNode):
         # Value of this node is an array (Ex: [1,2])
-        value = loader.construct_sequence(node)
+        value = cast(MutableSequence[Any], loader.construct_sequence(node))
 
     else:
         # Value of this node is an mapping (ex: {foo: bar})
-        value = loader.construct_mapping(node)
+        value = cast(MutableMapping[Any, Any], loader.construct_mapping(node))
 
     return {cfntag: value}
 
 
-def yaml_dump(dict_to_dump):
+def yaml_dump(dict_to_dump: Dict[str, Any]) -> str:
     """Dump the dictionary as a YAML document."""
     return yaml.safe_dump(dict_to_dump, default_flow_style=False)
 
 
-def yaml_parse(yamlstr):
+def yaml_parse(yamlstr: str) -> Dict[str, Any]:
     """Parse a yaml string."""
     try:
         # PyYAML doesn't support json as well as it should, so if the input
