@@ -3,13 +3,14 @@ from __future__ import annotations
 
 import copy
 import logging
-from typing import TYPE_CHECKING, Any, Dict, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, Optional, Union, cast
 
 from awacs import ecs
 from awacs.aws import Allow, Policy, Statement
 from awacs.helpers.trust import get_ecs_assumerole_policy
 from botocore.exceptions import ClientError
 
+from ...utils import BaseModel
 from . import utils
 
 if TYPE_CHECKING:
@@ -22,9 +23,53 @@ if TYPE_CHECKING:
 
 LOGGER = logging.getLogger(__name__)
 
+ECS_SERVICE_ROLE_NAME = "ecsServiceRole"
+ECS_SERVICE_ROLE_POLICY = Policy(
+    Version="2012-10-17",
+    Statement=[
+        Statement(
+            Effect=Allow,
+            Resource=["*"],
+            Action=[
+                ecs.CreateCluster,
+                ecs.DeregisterContainerInstance,
+                ecs.DiscoverPollEndpoint,
+                ecs.Poll,
+                ecs.Action("Submit*"),
+            ],
+        )
+    ],
+)
+
+
+class CreateEcsServiceRoleHookArgs(BaseModel):
+    """Hook arguments for ``create_ecs_service_role``."""
+
+    role_name: str = ECS_SERVICE_ROLE_NAME
+    """Name of the role to create."""
+
+
+class EnsureServerCertExistsHookArgs(BaseModel):
+    """Hook arguments for ``ensure_server_cert_exists``."""
+
+    cert_name: str
+    """Name of the certificate that should exist."""
+
+    path_to_certificate: Optional[str] = None
+    """Path to certificate file."""
+
+    path_to_chain: Optional[str] = None
+    """Path to chain file."""
+
+    path_to_private_key: Optional[str] = None
+    """Path to private key file."""
+
+    prompt: bool = True
+    """Whether to prompt to upload a certificate if one does not exist."""
+
 
 def create_ecs_service_role(
-    context: CfnginContext, *, role_name: str = "ecsServiceRole", **_: Any
+    context: CfnginContext, *__args: Any, **kwargs: Any
 ) -> bool:
     """Create ecsServiceRole IAM role.
 
@@ -32,39 +77,23 @@ def create_ecs_service_role(
 
     Args:
         context: Context instance. (passed in by CFNgin)
-        role_name: Name of the role to create.
 
     """
+    args = CreateEcsServiceRoleHookArgs.parse_obj(kwargs)
     client = context.get_session().client("iam")
 
     try:
         client.create_role(
-            RoleName=role_name,
+            RoleName=args.role_name,
             AssumeRolePolicyDocument=get_ecs_assumerole_policy().to_json(),
         )
     except ClientError as err:
         if "already exists" not in str(err):
             raise
-    policy = Policy(
-        Version="2012-10-17",
-        Statement=[
-            Statement(
-                Effect=Allow,
-                Resource=["*"],
-                Action=[
-                    ecs.CreateCluster,
-                    ecs.DeregisterContainerInstance,
-                    ecs.DiscoverPollEndpoint,
-                    ecs.Poll,
-                    ecs.Action("Submit*"),
-                ],
-            )
-        ],
-    )
     client.put_role_policy(
-        RoleName=role_name,
+        RoleName=args.role_name,
         PolicyName="AmazonEC2ContainerServiceRolePolicy",
-        PolicyDocument=policy.to_json(),
+        PolicyDocument=ECS_SERVICE_ROLE_POLICY.to_json(),
     )
     return True
 
@@ -82,7 +111,7 @@ def _get_cert_arn_from_response(
         ]["Arn"]
     return (
         cast("UploadServerCertificateResponseTypeDef", result)
-        .get("ServerCertificateMetadata", {})
+        .get("ServerCertificateMetadata", {"Arn": ""})
         .get("Arn", "")
     )
 
@@ -115,9 +144,7 @@ def _get_cert_contents(kwargs: Dict[str, Any]) -> Dict[str, Any]:
 
         paths[key] = path
 
-    parameters = {
-        "ServerCertificateName": kwargs.get("cert_name"),
-    }
+    parameters: Dict[str, str] = {}
 
     for key, path in paths.items():
         if not path:
@@ -137,48 +164,50 @@ def _get_cert_contents(kwargs: Dict[str, Any]) -> Dict[str, Any]:
         elif key == "chain":
             parameters["CertificateChain"] = contents
 
+    if parameters and "cert_name" in kwargs:
+        parameters["ServerCertificateName"] = kwargs["cert_name"]
+
     return parameters
 
 
 def ensure_server_cert_exists(
-    context: CfnginContext, *, cert_name: str, prompt: bool = True, **kwargs: Any
+    context: CfnginContext, *__args: Any, **kwargs: Any
 ) -> Dict[str, str]:
     """Ensure server cert exists.
 
     Args:
         context: CFNgin context object.
-        cert_name: Name of the certificate that should exist.
-        prompt: Whether to prompt to upload a certificate if one does not exist.
 
     Returns:
         Dict containing ``status``, ``cert_name``, and ``cert_arn``.
 
     """
+    args = EnsureServerCertExistsHookArgs.parse_obj(kwargs)
     client = context.get_session().client("iam")
     status = "unknown"
     try:
-        response = client.get_server_certificate(ServerCertificateName=cert_name)
+        response = client.get_server_certificate(ServerCertificateName=args.cert_name)
         cert_arn = _get_cert_arn_from_response(response)
         status = "exists"
-        LOGGER.info("certificate exists: %s (%s)", cert_name, cert_arn)
+        LOGGER.info("certificate exists: %s (%s)", args.cert_name, cert_arn)
     except ClientError:
-        if prompt:
+        if args.prompt:
             upload = input(
-                f"Certificate '{cert_name}' wasn't found. Upload it now? (yes/no) "
+                f"Certificate '{args.cert_name}' wasn't found. Upload it now? (yes/no) "
             )
             if upload != "yes":
                 return {}
 
-        parameters = _get_cert_contents(kwargs)
+        parameters = _get_cert_contents(args.dict())
         if not parameters:
             return {}
         response = client.upload_server_certificate(**parameters)
         cert_arn = _get_cert_arn_from_response(response)
         status = "uploaded"
-        LOGGER.info("uploaded certificate: %s (%s)", cert_name, cert_arn)
+        LOGGER.info("uploaded certificate: %s (%s)", args.cert_name, cert_arn)
 
     return {
         "status": status,
-        "cert_name": cert_name,
+        "cert_name": args.cert_name,
         "cert_arn": cert_arn,
     }
