@@ -2,8 +2,9 @@
 from __future__ import annotations
 
 import logging
-from typing import TYPE_CHECKING, Any, Dict, Optional
+from typing import TYPE_CHECKING, Any, Dict
 
+from ...utils import BaseModel
 from ..utils import create_route53_zone
 
 if TYPE_CHECKING:
@@ -12,22 +13,26 @@ if TYPE_CHECKING:
 LOGGER = logging.getLogger(__name__)
 
 
+class CreateDomainHookArgs(BaseModel):
+    """Hook arguments for ``create_domain``."""
+
+    domain: str
+    """Domain name for the Route 53 hosted zone to be created."""
+
+
 def create_domain(
-    context: CfnginContext, *, domain: Optional[str] = None, **_: Any
+    context: CfnginContext, *__args: Any, **kwargs: Any
 ) -> Dict[str, str]:
     """Create a domain within route53.
 
     Args:
         context: CFNgin context object.
-        domain: Domain name for the Route 53 hosted zone to be created.
 
     Returns:
         Dict containing ``domain`` and ``zone_id``.
 
     """
+    args = CreateDomainHookArgs.parse_obj(kwargs)
     client = context.get_session().client("route53")
-    if not domain:
-        LOGGER.error("domain argument or BaseDomain variable required but not provided")
-        return {}
-    zone_id = create_route53_zone(client, domain)
-    return {"domain": domain, "zone_id": zone_id}
+    zone_id = create_route53_zone(client, args.domain)
+    return {"domain": args.domain, "zone_id": zone_id}
